# Generated by Django 4.2.3 on 2023-07-13 15:10

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_project', '0021_auto_20210521_1202'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='customer',
            options={'default_permissions': ['add', 'change', 'delete', 'view', 'control'], 'ordering': ['pk']},
        ),
        migrations.AlterModelOptions(
            name='project',
            options={'default_permissions': ['add', 'change', 'delete', 'view', 'control'], 'ordering': ['pk']},
        ),
    ]
