# Generated by Django 4.2.3 on 2023-10-14 17:01

from django.db import migrations, models
import django.db.models.deletion
import djangoldp.fields


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_community', '0013_auto_20231014_1439'),
        ('auth', '0012_alter_user_first_name_max_length'),
        ('djangoldp_project', '0022_alter_customer_options_alter_project_options'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='businessprovider',
            options={'default_permissions': {'change', 'add', 'delete', 'control', 'view'}},
        ),
        migrations.AlterModelOptions(
            name='customer',
            options={'default_permissions': {'change', 'add', 'delete', 'control', 'view'}, 'ordering': ['pk']},
        ),
        migrations.AlterModelOptions(
            name='member',
            options={'default_permissions': {'change', 'add', 'delete', 'control', 'view'}},
        ),
        migrations.AlterModelOptions(
            name='project',
            options={'default_permissions': {'change', 'add', 'delete', 'control', 'view'}, 'ordering': ['pk']},
        ),
        migrations.AddField(
            model_name='project',
            name='admins',
            field=models.OneToOneField(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='admin_project', to='auth.group'),
        ),
        migrations.AddField(
            model_name='project',
            name='community',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='projects', to='djangoldp_community.community'),
        ),
        migrations.AddField(
            model_name='project',
            name='members',
            field=models.OneToOneField(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='project', to='auth.group'),
        ),
        migrations.AddField(
            model_name='project',
            name='public',
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name='businessprovider',
            name='urlid',
            field=djangoldp.fields.LDPUrlField(blank=True, db_index=True, null=True, unique=True),
        ),
        migrations.AlterField(
            model_name='customer',
            name='urlid',
            field=djangoldp.fields.LDPUrlField(blank=True, db_index=True, null=True, unique=True),
        ),
        migrations.AlterField(
            model_name='member',
            name='project',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='oldmembers', to='djangoldp_project.project'),
        ),
        migrations.AlterField(
            model_name='member',
            name='urlid',
            field=djangoldp.fields.LDPUrlField(blank=True, db_index=True, null=True, unique=True),
        ),
        migrations.AlterField(
            model_name='project',
            name='urlid',
            field=djangoldp.fields.LDPUrlField(blank=True, db_index=True, null=True, unique=True),
        ),
    ]
